@@ -30,7 +30,7 @@ func newTaskGraphCmd() *cobra.Command {
 
 func runTaskGraphCmd(cmd *cobra.Command, args []string) error {
 	manifestDir := args[0]
-	release, err := payload.LoadUpdate(manifestDir, "", "")
+	release, err := payload.LoadUpdate(manifestDir, "", "", payload.DefaultClusterProfile)
 	if err != nil {
 		return err
 	}
