@@ -11,8 +11,8 @@ import (
 	"k8s.io/utils/pointer"
 )
 
-// ApplyJob applies the required Job to the cluster.
-func ApplyJob(ctx context.Context, client batchclientv1.JobsGetter, required *batchv1.Job) (*batchv1.Job, bool, error) {
+// ApplyJobv1 applies the required Job to the cluster.
+func ApplyJobv1(ctx context.Context, client batchclientv1.JobsGetter, required *batchv1.Job) (*batchv1.Job, bool, error) {
 	existing, err := client.Jobs(required.Namespace).Get(ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
 		actual, err := client.Jobs(required.Namespace).Create(ctx, required, metav1.CreateOptions{})
