@@ -728,10 +728,11 @@ func (w *SyncWorker) apply(ctx context.Context, payloadUpdate *payload.Update, w
 		precreateObjects = true
 	}
 
-	// in specific modes, attempt to precreate a set of known types (currently ClusterOperator) without
-	// retries
-	if precreateObjects {
-		payload.RunGraph(ctx, graph, 8, func(ctx context.Context, tasks []*payload.Task) error {
+	// update each object
+	errs := payload.RunGraph(ctx, graph, maxWorkers, func(ctx context.Context, tasks []*payload.Task) error {
+		// in specific modes, attempt to precreate a set of known types (currently ClusterOperator) without
+		// retries
+		if precreateObjects {
 			for _, task := range tasks {
 				if err := ctx.Err(); err != nil {
 					return cr.ContextError(err)
@@ -744,22 +745,14 @@ func (w *SyncWorker) apply(ctx context.Context, payloadUpdate *payload.Update, w
 					klog.V(4).Infof("Skipping precreation of %s as unmanaged", task)
 					continue
 				}
-				if task.Manifest.Obj.GetName() == "baremetal" {
-					klog.V(4).Infof("Skipping precreation of %s, https://bugzilla.redhat.com/show_bug.cgi?id=1929917", task)
-					continue
-				}
 				if err := w.builder.Apply(ctx, task.Manifest, payload.PrecreatingPayload); err != nil {
 					klog.V(2).Infof("Unable to precreate resource %s: %v", task, err)
 					continue
 				}
 				klog.V(4).Infof("Precreated resource %s", task)
 			}
-			return nil
-		})
-	}
+		}
 
-	// update each object
-	errs := payload.RunGraph(ctx, graph, maxWorkers, func(ctx context.Context, tasks []*payload.Task) error {
 		for _, task := range tasks {
 			if err := ctx.Err(); err != nil {
 				return cr.ContextError(err)
